-- 成就任务
Lua_AchievementTaskPanel = class("Lua_AchievementTaskPanel", Lua_DisplayObject)
function Lua_AchievementTaskPanel:ctor(p)
	self:superCall("ctor", p);
end

function Lua_AchievementTaskPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.infoBg = UICreate.createUIAtlasImage(self.content, "task_altas", "xui_rcrw_window_10", 0, -38, 634, 940);

	self.rewardList = Lua_DragList.new(self.content, 624, 930, Lua_AxisDefine.Vertical);
	self.rewardList.tweenId = 2023;
	self.rewardList:setListCell(Lua_AchievementRewardItem, 624, 172, 1);
	self.rewardList:setCellSpacing(0, 5);
	self.rewardList:setLocation(0, -38, 0);
end

function Lua_AchievementTaskPanel:updateData()
	local idArr = DataCenter.taskData:getTaskIdsByMainType(Lua_TaskData.achievementTaskTask);
	self.rewardList:setArrayData(idArr);
end

function Lua_AchievementTaskPanel:dispose()
	if self.infoBg ~= nil then
		self.infoBg:dispose();
		self.infoBg = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
    self:superCall("dispose");
end










Lua_AchievementRewardItem = class("Lua_AchievementRewardItem", Lua_ListCell);
function Lua_AchievementRewardItem:ctor(p)
	self:superCall("ctor", p, "AchievementTaskItem_skin");
end

function Lua_AchievementRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardIcons = Lua_ItemIconList.new(self.content);
	self.rewardIcons.scaleVal = 0.7;
	self.rewardIcons.pivot = 1;
	self.rewardIcons:setLayout(133, 0, 10);
	self.rewardIcons:setLocation(-251, 0, 0);

	self.stateBtn:addClickFuntion(self, self.onBtnClick);
end

function Lua_AchievementRewardItem:setData(data)
	self._data = DataCenter.taskData:getSingleTaskVoById(data);
	if data == nil or self._data == nil then
		return;
	end

	self.explainTxt.text = self._data.desc;
	self.tipsTxt.text = self._data.advanceMessage;
	self.progressBar:setMaxValue(self._data.maxProgressVal);
	self.progressBar:setValue(self._data.curProgressVal);
	self.progressBar:setText(self._data.progressTxt);

	if self._data.isOpen then
		self.drawIcon:setAltas("common_altas_1", "xui_common_label_12");
	else
		self.drawIcon:setAltas("task_altas", "xui_rcrw_label_1");
	end
	self.drawIcon:resetSize();

	-- 0：未完成 1：完成 2：已领取
	if self._data.curReceiveState == 0 then
		self.stateBtn:setStyle(3);
		self.stateBtn:setLangValue(202800);
	elseif self._data.curReceiveState == 1 then
		self.stateBtn:setStyle(1);
		self.stateBtn:setLangValue(202801);
	end
	self.rewardIcons:setArrayData(self._data.reward);

	self.tipsTxt:setEnable(not self._data.isOpen);
	self.progressBar:setEnable(self._data.isOpen);
	self.stateBtn:setEnable(self._data.isOpen and self._data.curReceiveState ~= 2);
	self.drawIcon:setEnable(not self._data.isOpen or self._data.curReceiveState == 2);
	self:showRedDot(self._data.curReceiveState == 1);
end

function Lua_AchievementRewardItem:onPressClick()
	local checkItem = self:checkClick();
	if self.pressItem ~= nil and checkItem == self.pressItem then
		self.pressItem:onItemClick(nil);
	end
end

function Lua_AchievementRewardItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.rewardIcons.mainContent);
	local showArr = self.rewardIcons.showArr;
	for i = 1, showArr:getSize() do
		if showArr[i].isActive and showArr[i]:checkInBound(winPos.x, winPos.y) then
			return showArr[i];
		end
	end
	return nil;
end

function Lua_AchievementRewardItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.6, 0.6);
	end
end

function Lua_AchievementRewardItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.7, 0.7);
	end
end

function Lua_AchievementRewardItem:showRedDot(bShow)
	if bShow then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(275, 8, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_AchievementRewardItem:onBtnClick(go)
	if self._data.curReceiveState == 0 then
		if self._data.eventId ~= nil then
			DataCenter.funcPathUtil:gotoFunction(self._data.eventId, true);
		end
	elseif self._data.curReceiveState == 1 then
		local time = getTime();
		local deltaTime = time - DataCenter.taskData.lastReceivedTime;
		if deltaTime > DataCenter.taskData.receiveDeltaTime then
			DataCenter.taskData.lastReceivedTime = time;
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sCompleteTask(self._data.mainType, self._data.conditionId);
		else
			OperateAlert.showLangValue(202810);
		end
	end
end

function Lua_AchievementRewardItem:dispose()
	if self.rewardIcons ~= nil then
		self.rewardIcons:dispose();
		self.rewardIcons = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;
	self.pressItem = nil;
	self:superCall("dispose");
end