-- 活跃战令
Lua_ActiveWarPanel = class("Lua_ActiveWarPanel", Lua_DisplayObject)
function Lua_ActiveWarPanel:ctor(p)
	self:superCall("ctor", p, "ActiveWarPanel_skin");
end

function Lua_ActiveWarPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 606, 636, Lua_AxisDefine.Vertical);
	self.rewardList.tweenId = 2023;
	self.rewardList.delayTween = true;
	self.rewardList:setListCell(Lua_ActiveWarItem, 606, 143, 1);
	self.rewardList:setRectPivot(1);
	self.rewardList:setCellSpacing(0, 1);
	self.rewardList:setLocation(0, 153, 0);

	self.ruleBtn:addClickFuntion(self, self.onRuleBtnClick);
	self.primaryWarBg:addClickFuntion(self, self.onPrimaryLockClick);
	self.seniorWarBg:addClickFuntion(self, self.onSeniorLockClick);
	self.getBtn:addClickFuntion(self, self.onGetAllClick);

	self:addLuaEvent("UPDATE_ACTIVEWAR_INFO", self, self.updateActiveWarInfo);
	self:addLuaEvent("ON_ACTIVEWAR_PRIMARYLOCK_CLICK", self, self.onPrimaryLockClick);
	self:addLuaEvent("ON_ACTIVEWAR_SENIORLOCK_CLICK", self, self.onSeniorLockClick);
	Lua_ProxyManager.getProxy("Lua_TaskProxy"):sTaskActiveWarInfo(1);
end

function Lua_ActiveWarPanel:updateActiveWarInfo()
	self:startTimer();
	self:updateLeftTime();
	self:updateWarsState();

	local isGray = false;
	if not DataCenter.taskData.primaryLockState and not DataCenter.taskData.seniorLockState then
		isGray = true;
	else
		if not DataCenter.taskData.activeWarReward then
			isGray = true;
		end
	end
	self.getBtn:setGray(isGray);

	self.rewardList:setArrayData(DataCenter.taskData.acitveWarArr);
	if not self.isFirstIn then
		self.isFirstIn = true;

		local moveIndex = (DataCenter.taskData.activeWarShowIdx % 1000) or 1;
		moveIndex = moveIndex > 1 and (moveIndex - 1) or moveIndex;
		self.rewardList:moveToIndex(moveIndex, true);
	end
end

function Lua_ActiveWarPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_ActiveWarPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_ActiveWarPanel:updateLeftTime()
	local time = DataCenter.taskData.activeWarTime - DataCenter.roleData.serverTime;
	if time <= 0 then
		time = 0;
		self:endTimer();
	end
	self.residueTime.text = LanUtil.formateStr(202813, Lua_TimeTransform.transSeconds20(time, true, true, true));
end

function Lua_ActiveWarPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

-- 战令状态显示
function Lua_ActiveWarPanel:updateWarsState()
	-- 初级战令解锁状态显示
	local state = DataCenter.taskData.primaryLockState;
	local str;
	if state then
		str = LanUtil.getValue(202814);
	else
		local list = DataCenter.taskUtil.lockRewardlist;
		local tvo = Lua_ToolVo.createToolVo(list[1]);
		str = LanUtil.formateStr(202815, spliceIconStr(tvo.iconAtlas, tvo.iconSprite, tvo.iconWidth * 0.7, tvo.iconHeight * 0.7), list[2]);
	end
	self.primaryTipsTxt.text = str;
	self.primaryLockSp:setEnable(not state);

	-- 高级战令解锁状态显示
	state = DataCenter.taskData.seniorLockState;
	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(DataCenter.taskUtil.activeWarRechargeId);	
	self.seniorTipTxt.text = state and LanUtil.getValue(202814) or LanUtil.formateStr(202816, rechargeInfo.money);
	self.seniorLockSp:setEnable(not state);
end

function Lua_ActiveWarPanel:onRuleBtnClick(go)
	local tipsData = { des = 202817, posX = 150, posY = 250, needAdapt = false };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ActiveWarPanel:onPrimaryLockClick()
	if not DataCenter.taskData.primaryLockState then 
		Lua_WindowUtil.openWin("Lua_UnlockPrimaryWarWindow", Lua_WinParam.ACTION_OPEN, Lua_TaskData.primaryWarStyle);
	end
end

function Lua_ActiveWarPanel:onSeniorLockClick()
	if not DataCenter.taskData.seniorLockState then
		local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(DataCenter.taskUtil.activeWarRechargeId);
		DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
			tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
	end
end

function Lua_ActiveWarPanel:onGetAllClick(go)
	local isLock = DataCenter.taskData.primaryLockState or DataCenter.taskData.seniorLockState;
	if isLock and DataCenter.taskData.activeWarReward then
		Lua_ProxyManager.getProxy("Lua_TaskProxy"):sTaskActiveWarReward(0, 0); -- 一键领取
	else
		OperateAlert.showLangValue(202819);
	end
end

function Lua_ActiveWarPanel:updateData()
end

function Lua_ActiveWarPanel:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self:endTimer();
    self:superCall("dispose");
end










Lua_ActiveWarItem = class("Lua_ActiveWarItem", Lua_ListCell);
function Lua_ActiveWarItem:ctor(p)
	self:superCall("ctor", p, "ActiveWarItem_skin");
end

function Lua_ActiveWarItem:buildShowItem()
	self:superCall("buildShowItem");

	-- 初级战令奖励
	self.primaryItem = Lua_ActiveWarRewardItem.new(self.content);
	self.primaryItem:setLocation(-217, 0, 0);

	-- 高级战令奖励列表
	self.seniorList = Lua_DragList.new(self.content, 181, 87, Lua_AxisDefine.Horizontal);
	self.seniorList:setListCell(Lua_ActiveWarRewardItem, 87, 87, 1);
	self.seniorList:setRectPivot(3);
	self.seniorList:setCellSpacing(7, 0);
	self.seniorList:setLocation(-130, 0, 0);
	self:setSubList(self.seniorList);

	self.stateTxt.clickScale = false;
	self.stateTxt:addClickFuntion(self, self.onStateClick);
end

function Lua_ActiveWarItem:setData(data)
	self._data = DataCenter.taskData:getActiveWarVoById(data);
	if data == nil or self._data == nil then
		return;
	end

	-- 初级战令
	self.primaryInfo = self._data.primaryList[1];
	self.primaryItem:setData(self.primaryInfo);

	-- 高级战令
	self.seniorInfo = self._data.seniorList[1];
	self.seniorList.canDrag = #self._data.seniorList > 2;
	self.seniorList:setArrayData(self._data.seniorList);

	local curPoint = DataCenter.taskData.activeWarPoint;
	curPoint = curPoint >= self._data.process and self._data.process or curPoint;
	self.isComplete = curPoint >= self._data.process;
	local color = self.isComplete and "43261C" or "ED4C30";
	self.tipTxt.text = LanUtil.formateStr(202818, color, curPoint, self._data.process);

	local isPrimaryLock = self.primaryInfo.lockState;
	local primaryState = self.primaryInfo.rewardState;
	local isSeniorLock = self.seniorInfo.lockState;
	local seniorState = self.seniorInfo.rewardState;
	local langId;
	if self.isComplete then -- 满足活跃度
		if isPrimaryLock and isSeniorLock then -- 都解锁
			if primaryState == 1 or seniorState == 1 then
				langId = 202822; -- 可领取
			elseif primaryState == 2 and seniorState == 2 then
				langId = 202824; -- 已领取
			end
		elseif not isPrimaryLock and not isSeniorLock then -- 都未解锁
			langId = 202820; -- 激活可领取
		else -- 一个解锁
			if isPrimaryLock then
				if primaryState == 1 then
					langId = 202822; -- 可领取
				elseif primaryState == 2 then
					langId = 202821; -- 领取更多
				end
			else
				if seniorState == 1 then
					langId = 202822; -- 可领取
				elseif seniorState == 2 then
					langId = 202821; -- 领取更多
				end
			end
		end
	else -- 未满足活跃度
		langId = 202823; -- 未完成
	end
	self.stateTxt:setLangValue(langId);
	-- print(isPrimaryLock, primaryState, isSeniorLock, seniorState);
end

function Lua_ActiveWarItem:onStateClick(go)
	local isPrimaryLock = self.primaryInfo.lockState;
	local primaryState = self.primaryInfo.rewardState;
	local isSeniorLock = self.seniorInfo.lockState;
	local seniorState = self.seniorInfo.rewardState;
	if self.isComplete then -- 满足活跃度
		if (isPrimaryLock and not isSeniorLock) or (not isPrimaryLock and isSeniorLock) then -- 一个解锁
			if isPrimaryLock then
				if primaryState ~= 1 then
					Lua_MsgUtil.callFunc("ON_ACTIVEWAR_SENIORLOCK_CLICK");
				end
			else
				if seniorState ~= 1 then
					Lua_MsgUtil.callFunc("ON_ACTIVEWAR_PRIMARYLOCK_CLICK");
				end
			end
		elseif not isPrimaryLock and not isSeniorLock then -- 都未解锁
			Lua_MsgUtil.callFunc("ON_ACTIVEWAR_PRIMARYLOCK_CLICK");
		end
	else -- 未满足活跃度
		Lua_WindowUtil.openWin("Lua_TaskBaseWindow", Lua_WinParam.ACTION_OPEN, {main_id = Lua_TaskData.dailyTask});
	end
end

function Lua_ActiveWarItem:onPressClick()
	local checkItem = self:checkClick();
	if self.pressItem ~= nil and checkItem == self.pressItem then
		self.pressItem:onUpClick();
	end
end

function Lua_ActiveWarItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.primaryItem.mainContent);
	if self.primaryItem.rewardItem:checkInBound(winPos.x, winPos.y) then
		return self.primaryItem;
	end

	local showArr = self.seniorList.showList;
	for i = 1, showArr:getSize() do
		winPos = LuaUtil.getTouchPosInverseObj(showArr[i].mainContent);
		if showArr[i].rewardItem.isActive and showArr[i].rewardItem:checkInBound(winPos.x, winPos.y) then
			return showArr[i];
		end
	end
	return nil;
end

function Lua_ActiveWarItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.9, 0.9);
	end
end

function Lua_ActiveWarItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:setScale(1, 1);
	end
end

function Lua_ActiveWarItem:dispose()
	if self.primaryItem ~= nil then
		self.primaryItem:dispose();
		self.primaryItem = nil;
	end
	if self.seniorList ~= nil then
		self.seniorList:dispose();
		self.seniorList = nil;
	end
	self.pressItem = nil;
	self:superCall("dispose");
end










Lua_ActiveWarRewardItem = class("Lua_ActiveWarRewardItem", Lua_ListCell);
function Lua_ActiveWarRewardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ActiveWarRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardItem = Lua_ItemIcon.new(self.content);
	self.rewardItem:setCanClick(false);
	self.rewardItem:setScale(0.7, 0.7);
end

function Lua_ActiveWarRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local tvo = Lua_ToolVo.createToolVo(data.itemList[1], data.itemList[2]);
	self.rewardItem:setData(tvo);
	self.rewardItem:setEquipLock(not data.lockState, -48, 45);
	self.rewardItem:setDrawMask(data.rewardState == 2); -- 已领取图标是否显示

	self:showRedDot(data.rewardState == 1 and data.lockState);-- 已解锁可领取
end

function Lua_ActiveWarRewardItem:showRedDot(bShow)
    if bShow then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content);
            self.redPoint:createRedPointEff();
            self.redPoint:setLocation(27, 27, 0);
            self.redPoint:setScale(0.9, 0.9);
        end
        self.redPoint:updateRedPointShow(true);
    else
        if self.redPoint ~= nil then
            self.redPoint:updateRedPointShow(false);
        end
    end
end

function Lua_ActiveWarRewardItem:onUpClick()
	if self._data == nil then
		return;
	end

	if self._data.rewardState ~= 1 then -- 奖励不可领取（即活跃度未达标时）或已领取时显示道具信息
		DataCenter.packUtil:showItemInfo(self.rewardItem.data);
	else
		if not self._data.lockState then -- 活跃度达标，但未解锁时，弹解锁窗口
			if self._data.warType == Lua_TaskData.primaryWarStyle then -- 初级
				Lua_MsgUtil.callFunc("ON_ACTIVEWAR_PRIMARYLOCK_CLICK");
			else -- 高级
				Lua_MsgUtil.callFunc("ON_ACTIVEWAR_SENIORLOCK_CLICK");
			end
		else -- 活跃度达标且该战令解锁时，领取奖励
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sTaskActiveWarReward(self._data.id, self._data.warType);
		end
	end
end

function Lua_ActiveWarRewardItem:dispose()
	if self.rewardItem ~= nil then
		self.rewardItem:dispose();
		self.rewardItem = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end