-- 日常任务功能任务item
Lua_TaskRewardItem = class("Lua_TaskRewardItem", Lua_ListCell);
function Lua_TaskRewardItem:ctor(p)
	self:superCall("ctor", p, "TaskItem_skin");
end

function Lua_TaskRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.tipsTxt:setEnable(false);

	self.rewardIcons = Lua_ItemIconList.new(self.content);
	self.rewardIcons.scaleVal = 0.64;
	self.rewardIcons:setLayout(135, 0, 10);
	self.rewardIcons:setLocation(43, 1, 0);

	self.stateBtn:addClickFuntion(self, self.onBtnClick);
end

function Lua_TaskRewardItem:setData(data)
	self._data = DataCenter.taskData:getSingleTaskVoById(data);
	if data == nil or self._data == nil then
		return;
	end

	self.explainTxt.text = self._data.desc;
	self.tipsTxt.text = self._data.advanceMessage;
	self.completeTxt.text = self._data.progressTxt;
	self.progressBar:setMaxValue(self._data.maxProgressVal);
	self.progressBar:setValue(self._data.curProgressVal);

	if self._data.isOpen then
		self.drawIcon:setAltas("common_altas_1", "xui_common_label_12");
	else
		self.drawIcon:setAltas("task_altas", "xui_rcrw_label_1");
	end
	self.drawIcon:resetSize();

	-- 0：未完成 1：完成 2：已领取
	if self._data.curReceiveState == 0 then
		self.stateBtn:setStyle(3);
		self.stateBtn:setLangValue(202800);
	elseif self._data.curReceiveState == 1 then
		self.stateBtn:setStyle(1);
		self.stateBtn:setLangValue(202801);
	end
	self.rewardIcons:setArrayData(self._data.reward);

	self.tipsTxt:setEnable(not self._data.isOpen);
	self.completeTxt:setEnable(self._data.isOpen);
	self.progressBar:setEnable(self._data.isOpen);
	self.stateBtn:setEnable(self._data.isOpen and self._data.curReceiveState ~= 2);
	self.drawIcon:setEnable(not self._data.isOpen or self._data.curReceiveState == 2);
	self:showRedDot(self._data.curReceiveState == 1);
end

function Lua_TaskRewardItem:onPressClick()
	local checkItem = self:checkClick();
	if self.pressItem ~= nil and checkItem == self.pressItem then
		self.pressItem:onItemClick(nil);
	end
end

function Lua_TaskRewardItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.rewardIcons.mainContent);
	local showArr = self.rewardIcons.showArr;
	for i = 1, showArr:getSize() do
		if showArr[i].isActive and showArr[i]:checkInBound(winPos.x, winPos.y) then
			return showArr[i];
		end
	end
	return nil;
end

function Lua_TaskRewardItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.54, 0.54);
	end
end

function Lua_TaskRewardItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.64, 0.64);
	end
end

function Lua_TaskRewardItem:showRedDot(bShow)
	if bShow then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(278, 17, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_TaskRewardItem:onBtnClick(go)
	if self._data.curReceiveState == 0 then
		if self._data.eventId ~= nil then
			DataCenter.funcPathUtil:gotoFunction(self._data.eventId, true)
		end
	elseif self._data.curReceiveState == 1 then
		local time = getTime();
		local deltaTime = time - DataCenter.taskData.lastReceivedTime;
		if deltaTime > DataCenter.taskData.receiveDeltaTime then
			DataCenter.taskData.lastReceivedTime = time;
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sCompleteTask(self._data.mainType, self._data.id);
		else
			OperateAlert.showLangValue(202810);
		end
	end
end

function Lua_TaskRewardItem:dispose()
	if self.rewardIcons ~= nil then
		self.rewardIcons:dispose();
		self.rewardIcons = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;
	self.pressItem = nil;
	self:superCall("dispose");
end